"snp.matrix" as dependent variable, this function first fits a
"base" logistic regression model and then carries out a score test for
the addition of further term(s). The Hardy-Weinberg
assumption can be relaxed by use of a "robust" option.
snp.lhs.tests(snp.data, base.formula, add.formula, subset, snp.subset, data = sys.parent(), robust = FALSE, control=glm.test.control(maxit=20, epsilon=1.e-4, R2Max=0.98))"snp.matrix" or "X.snp.matrix" formula object describing the base model,
with dependent variable omitted formula object describing the additional
terms to be tested, also with dependent variable omittedbase.formula,
add.formula and subset are to be evaluatedTRUE, a test which does not assume
Hardy-Weinberg equilibrium will be useddata argument is supplied, the snp.data and
data objects are aligned by rowname. Otherwise all variables in
the model formulae are assumed to be stored in the same order as the
columns of the snp.data object.
glm.test.control,snp.rhs.tests
single.snp.tests, snp.matrix-class,
X.snp.matrix-classdata(testdata)
slt1 <- snp.lhs.tests(Autosomes[,1:10], ~cc, ~region, data=subject.data)
print(slt1)
slt2 <- snp.lhs.tests(Autosomes[,1:10], ~strata(region), ~cc,
data=subject.data)
print(slt2)
Run the code above in your browser using DataLab